This optional SDK surface uses nanonext to expose the same bebelRAgent
object used by the console. It is intentionally small and not an OpenAI API:
clients call JSON-RPC methods such as turn, tools/list, and
session/transcript.
This optional SDK surface uses nanonext to expose the same bebelRAgent
object used by the console. It is intentionally small and not an OpenAI API:
clients call JSON-RPC methods such as turn, tools/list, and
session/transcript.